@@ -29,8 +29,7 @@ from .vm_manager import VMEntry
 from .desktop_file_manager import ApplicationInfo
 
 import gi
-
-gi.require_version("Gtk", "3.0")
+gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk, Gdk, GLib, Pango
 
 
@@ -39,7 +38,6 @@ class LimitedWidthLabel(Gtk.Label):
     Gtk.Label, but with ellipsization and capped at 35 characters wide
     (which is not coincidentally 4 characters more than maximum VM name length)
     """
-
     def __init__(self, label_text=None):
         """
         :param label_text: optional text of the newly instantiated label
@@ -54,7 +52,6 @@ class LimitedWidthLabel(Gtk.Label):
 
 class HoverEventBox(Gtk.EventBox):
     """An EventBox that grabs provided widget on mouse hover."""
-
     def __init__(self, focus_widget: Gtk.Widget):
         super().__init__()
         self.mouse = False
@@ -62,8 +59,8 @@ class HoverEventBox(Gtk.EventBox):
 
         self.add_events(Gdk.EventMask.ENTER_NOTIFY_MASK)
         self.add_events(Gdk.EventMask.LEAVE_NOTIFY_MASK)
-        self.connect("enter-notify-event", self._enter_event)
-        self.connect("leave-notify-event", self._leave_event)
+        self.connect('enter-notify-event', self._enter_event)
+        self.connect('leave-notify-event', self._leave_event)
 
     def _enter_event(self, *_args):
         self.mouse = True
@@ -84,7 +81,6 @@ class HoverListBox(Gtk.ListBoxRow):
     Gtk.ListBoxRow, but selects itself on hover (after a timeout specified in
     constants.py)
     """
-
     def __init__(self):
         super().__init__()
         self.mouse = False
@@ -94,7 +90,7 @@ class HoverListBox(Gtk.ListBoxRow):
         self.event_box.add(self.main_box)
         self.add(self.event_box)
 
-        self.connect("focus-in-event", self._on_focus)
+        self.connect('focus-in-event', self._on_focus)
 
     def _on_focus(self, *_args):
         if self.get_mapped():
@@ -107,14 +103,13 @@ class SelfAwareMenu(Gtk.Menu):
     Gtk.Menu, but the class has a counter of number of currently opened menus.
     There can be only one menu open at a time.
     """
-
     OPEN_MENUS = 0
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
-        self.get_style_context().add_class("right_menu")
-        self.connect("realize", self._add_to_open)
-        self.connect("unrealize", self._remove_from_open)
+        self.get_style_context().add_class('right_menu')
+        self.connect('realize', self._add_to_open)
+        self.connect('unrealize', self._remove_from_open)
 
     @staticmethod
     def _add_to_open(*_args):
@@ -129,13 +124,12 @@ class FavoritesMenu(SelfAwareMenu):
     """
     Menu for showing add to favorites option.
     """
-
     def __init__(self, app_info_getter: Callable[[], ApplicationInfo]):
         super().__init__()
         self.app_info_getter = app_info_getter
 
-        self.add_menu_item = Gtk.CheckMenuItem(label="Add to favorites")
-        self.add_menu_item.connect("activate", self._add_to_favorites)
+        self.add_menu_item = Gtk.CheckMenuItem(label='Add to favorites')
+        self.add_menu_item.connect('activate', self._add_to_favorites)
         self.add(self.add_menu_item)
         self.show_all()
 
@@ -146,7 +140,7 @@ class FavoritesMenu(SelfAwareMenu):
         """
         if self.app_info_getter():
             for entry in self.app_info_getter().entries:
-                if type(entry).__name__ == "FavoritesAppEntry":
+                if type(entry).__name__ == 'FavoritesAppEntry':
                     return True
         return False
 
@@ -155,18 +149,12 @@ class FavoritesMenu(SelfAwareMenu):
         "Add to favorites" action: sets appropriate VM feature
         """
         target_vm = self.app_info_getter().vm
-        entry_name = self.app_info_getter().entry_name
-        if not entry_name:
-            return
-
         if not target_vm:
             target_vm = self.app_info_getter().qapp.domains[
-                self.app_info_getter().qapp.local_name
-            ]
+                self.app_info_getter().qapp.local_name]
 
-        add_to_feature(
-            target_vm, constants.FAVORITES_FEATURE, entry_name
-        )  # type: ignore
+        add_to_feature(target_vm, constants.FAVORITES_FEATURE,
+                       self.app_info_getter().entry_name)  # type: ignore
 
     def set_menu_state(self):
         """
@@ -177,10 +165,8 @@ class FavoritesMenu(SelfAwareMenu):
 
         :return:
         """
-        if (
-            getattr(self.get_parent(), "ephemeral_vm", False)
-            or not self.app_info_getter()
-        ):
+        if (getattr(self.get_parent(), 'ephemeral_vm', False) or
+                not self.app_info_getter()):
             self.add_menu_item.set_active(False)
             self.add_menu_item.set_sensitive(False)
         else:
@@ -194,17 +180,14 @@ class NetworkIndicator(Gtk.Box):
     Network Indicator Gtk.Box - changes appearance when set_network_state is
     called.
     """
-
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
         self.icon_size = Gtk.IconSize.LARGE_TOOLBAR
         self.network_on: Gtk.Image = Gtk.Image.new_from_pixbuf(
-            load_icon("qappmenu-networking-yes", self.icon_size)
-        )
+            load_icon('qappmenu-networking-yes', self.icon_size))
         self.network_off: Gtk.Image = Gtk.Image.new_from_pixbuf(
-            load_icon("qappmenu-networking-no", self.icon_size)
-        )
+            load_icon('qappmenu-networking-no', self.icon_size))
 
         _, height, _ = Gtk.icon_size_lookup(self.icon_size)
         self.network_on.set_size_request(-1, height * 1.3)
@@ -213,13 +196,13 @@ class NetworkIndicator(Gtk.Box):
         self.pack_end(self.network_on, False, True, 10)
         self.pack_end(self.network_off, False, True, 10)
 
-        self.network_on.set_tooltip_text("Qube is networked")
-        self.network_off.set_tooltip_text("Qube is not networked")
+        self.network_on.set_tooltip_text('Qube is networked')
+        self.network_off.set_tooltip_text('Qube is not networked')
 
         self.network_on.set_no_show_all(True)
         self.network_off.set_no_show_all(True)
 
-        self.get_style_context().add_class("network_indicator")
+        self.get_style_context().add_class('network_indicator')
 
     def set_network_state(self, state: bool):
         """
@@ -235,20 +218,20 @@ class SettingsEntry(Gtk.ListBoxRow):
     """
     Gtk.ListBoxRow especially for a (run VM) Settings entry.
     """
-
     def __init__(self, desktop_file_manager):
         super().__init__()
         self.desktop_file_manager = desktop_file_manager
         self.event_box = HoverEventBox(focus_widget=self)
         self.hbox = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
         self.event_box.add(self.hbox)
-        self.settings_icon = Gtk.Image.new_from_pixbuf(load_icon("settings-black"))
+        self.settings_icon = Gtk.Image.new_from_pixbuf(
+            load_icon('settings-black'))
         self.hbox.pack_start(self.settings_icon, False, False, 5)
         self.settings_label = Gtk.Label(label="Settings", xalign=0)
         self.hbox.pack_start(self.settings_label, False, False, 5)
-        self.get_style_context().add_class("app_entry")
+        self.get_style_context().add_class('app_entry')
         self.add(self.event_box)
-        self.event_box.connect("button-press-event", self.show_menu)
+        self.event_box.connect('button-press-event', self.show_menu)
 
         self.menu = FavoritesMenu(self.get_appinfo)
 
@@ -257,21 +240,19 @@ class SettingsEntry(Gtk.ListBoxRow):
     def run_app(self, vm):
         """Run settings for specified vm."""
         # pylint: disable=consider-using-with
-        subprocess.Popen(["qubes-vm-settings", vm.name], stdin=subprocess.DEVNULL)
+        subprocess.Popen(
+            ['qubes-vm-settings', vm.name], stdin=subprocess.DEVNULL)
         self.get_toplevel().get_application().hide_menu()
 
     def get_appinfo(self) -> ApplicationInfo:
         """Get relevant app_info for currently selected vm"""
-        vm_entry: VMEntry = (
-            self.get_toplevel().get_application().get_currently_selected_vm()
-        )
+        vm_entry: VMEntry = (self.get_toplevel().get_application().
+                             get_currently_selected_vm())
         return self.desktop_file_manager.get_app_info_by_name(
-            vm_entry.settings_desktop_file_name
-        )
+            vm_entry.settings_desktop_file_name)
 
-    def update_state(self, vm_entry: VMEntry, apps_tab: bool = False):
+    def update_state(self, state):  # pylint: disable=unused-argument
         """Update state: should be always visible."""
-        # pylint: disable=unused-argument
         self.show_all()
 
     def show_menu(self, _widget, event):
@@ -289,10 +270,8 @@ class VMRow(HoverListBox):
     """
     Helper widget representing a VM row.
     """
-
-    def __init__(
-        self, vm_entry: VMEntry, show_dispvm_inheritance: Optional[bool] = True
-    ):
+    def __init__(self, vm_entry: VMEntry,
+                 show_dispvm_inheritance: Optional[bool] = True):
         """
         :param vm_entry: VMEntry object, stored and managed by VMManager
         :param show_dispvm_inheritance: bool, should dispvm children be shown
@@ -302,15 +281,15 @@ class VMRow(HoverListBox):
         self.vm_entry = vm_entry
         self.vm_name = vm_entry.vm_name
         self.show_dispvm_inheritance = show_dispvm_inheritance
-        self.get_style_context().add_class("vm_entry")
+        self.get_style_context().add_class('vm_entry')
 
         self.icon_img = Gtk.Image()
         self.dispvm_icon = Gtk.Image()
         # add the icon for dispvm parent existing
         if self.vm_entry.parent_vm:
-            dispvm_icon_img = load_icon("qappmenu-dispvm-child", None, 15)
+            dispvm_icon_img = load_icon('qappmenu-dispvm-child', None, 15)
             self.dispvm_icon.set_from_pixbuf(dispvm_icon_img)
-            self.dispvm_icon.get_style_context().add_class("dispvm_icon")
+            self.dispvm_icon.get_style_context().add_class('dispvm_icon')
             self.dispvm_icon.set_valign(Gtk.Align.START)
             self.main_box.pack_start(self.dispvm_icon, False, False, 2)
             self.dispvm_icon.set_no_show_all(True)
@@ -319,41 +298,35 @@ class VMRow(HoverListBox):
         self.label = Gtk.Label(label=self.vm_entry.vm_name)
         self.main_box.pack_start(self.label, False, False, 2)
 
-        self.update_contents(
-            update_power_state=True,
-            update_label=True,
-            update_has_network=True,
-            update_type=True,
-        )
+        self.update_contents(update_power_state=True, update_label=True,
+                             update_has_network=True, update_type=True)
 
     def update_style(self, update_power_state: bool = True):
         """Update own style, based on whether VM is running or not and
         what type it has."""
         style_context: Gtk.StyleContext = self.get_style_context()
         if self.vm_entry.is_dispvm_template:
-            style_context.add_class("dvm_template_entry")
+            style_context.add_class('dvm_template_entry')
         elif self.vm_entry.parent_vm:
             # has a parent VM means that it should have arrow etc.
-            style_context.add_class("dispvm_entry")
+            style_context.add_class('dispvm_entry')
         else:
-            style_context.remove_class("dispvm_entry")
-            style_context.remove_class("dvm_template_entry")
+            style_context.remove_class('dispvm_entry')
+            style_context.remove_class('dvm_template_entry')
 
         if update_power_state:
-            if self.vm_entry.power_state == "Running":
-                style_context.add_class("running_vm")
+            if self.vm_entry.power_state == 'Running':
+                style_context.add_class('running_vm')
             else:
-                style_context.remove_class("running_vm")
+                style_context.remove_class('running_vm')
 
         self.dispvm_icon.set_visible(self.show_dispvm_inheritance)
 
-    def update_contents(
-        self,
-        update_power_state=False,
-        update_label=False,
-        update_has_network=False,
-        update_type=False,
-    ):
+    def update_contents(self,
+                        update_power_state=False,
+                        update_label=False,
+                        update_has_network=False,
+                        update_type=False):
         """
         Update own contents (or related widgets, if applicable) based on state
         change.
@@ -389,41 +362,35 @@ class VMRow(HoverListBox):
 
 class SearchVMRow(VMRow):
     """VM Row used for the Search tab."""
-
-    def update_contents(
-        self,
-        update_power_state=False,
-        update_label=False,
-        update_has_network=False,
-        update_type=False,
-    ):
+    def update_contents(self,
+                        update_power_state=False,
+                        update_label=False,
+                        update_has_network=False,
+                        update_type=False):
         """
         Search rows do not show power state.
         """
-        super().update_contents(
-            update_power_state=False,
-            update_label=update_label,
-            update_has_network=False,
-            update_type=update_type,
-        )
+        super().update_contents(update_power_state=False,
+                                update_label=update_label,
+                                update_has_network=False,
+                                update_type=update_type)
 
 
 class AnyVMRow(HoverListBox):
     """Generic Any VM row for search purposes."""
-
     def __init__(self):
         super().__init__()
         self.vm_name = None
-        self.sort_order = ""
-        self.get_style_context().add_class("vm_entry")
+        self.sort_order = ''
+        self.get_style_context().add_class('vm_entry')
 
         icon_img = Gtk.Image()
-        icon_vm = load_icon("qubes-logo-icon")
+        icon_vm = load_icon('qubes-logo-icon')
         icon_img.set_from_pixbuf(icon_vm)
         self.main_box.pack_start(icon_img, False, False, 2)
 
         self.label = Gtk.Label()
-        self.label.set_markup("<b>Any qube</b>")
+        self.label.set_markup('<b>Any qube</b>')
         self.main_box.pack_start(self.label, False, False, 2)
         self.show_all()
 
@@ -433,11 +400,10 @@ class ControlRow(Gtk.ListBoxRow):
     Gtk.ListBoxRow representing one of the VM control options: start/shutdown/
     pause etc.
     """
-
     def __init__(self):
         super().__init__()
         self.row_label = LimitedWidthLabel()
-        self.get_style_context().add_class("app_entry")
+        self.get_style_context().add_class('app_entry')
         self.event_box = HoverEventBox(focus_widget=self)
         self.add(self.event_box)
         box = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
@@ -450,7 +416,7 @@ class ControlRow(Gtk.ListBoxRow):
         self.show_all()
         self.command = None
 
-    def update_state(self, vm_entry: VMEntry):
+    def update_state(self, state):
         """
         Update own state (visibility/text/sensitivity) based on provided VM
         state.
@@ -471,23 +437,20 @@ class StartControlItem(ControlRow):
     shutdown if it's running, unpause if it's paused, and kill if it's
     transient.
     """
-
     def __init__(self, desktop_file_manager):
         super().__init__()
         self.desktop_file_manager = desktop_file_manager
         self.state = None
-        self.event_box.connect("button-press-event", self.show_menu)
+        self.event_box.connect('button-press-event', self.show_menu)
 
         self.menu = FavoritesMenu(self.get_appinfo)
 
     def get_appinfo(self) -> ApplicationInfo:
         """Get relevant app_info for currently selected vm"""
-        vm_entry: VMEntry = (
-            self.get_toplevel().get_application().get_currently_selected_vm()
-        )
+        vm_entry: VMEntry = (self.get_toplevel().get_application().
+                             get_currently_selected_vm())
         return self.desktop_file_manager.get_app_info_by_name(
-            vm_entry.settings_desktop_file_name
-        )
+            vm_entry.settings_desktop_file_name)
 
     def show_menu(self, _widget, event):
         """
@@ -498,54 +461,36 @@ class StartControlItem(ControlRow):
         if event.button == 3:
             self.menu.popup_at_pointer(None)  # None means current event
 
-    def update_state(self, vm_entry: VMEntry, apps_tab: bool = False):
+    def update_state(self, state):
         """
         Update own state (visibility/text/sensitivity) based on provided VM
         state.
         """
-        vm_name = vm_entry.vm_name
-        is_dispvm_template = vm_entry.is_dispvm_template
-        self.state = vm_entry.power_state
+        self.state = state
+        if state == 'Running':
+            self.row_label.set_label('Shutdown qube')
+            self.command = 'qvm-shutdown'
+            self.icon.set_from_pixbuf(load_icon("qappmenu-shutdown", size=None,
+                                                pixel_size=15))
+            return
+        if state == 'Transient':
+            self.row_label.set_label('Kill qube')
+            self.command = 'qvm-kill'
+            self.icon.set_from_pixbuf(load_icon("qappmenu-shutdown", size=None,
+                                                pixel_size=15))
+            return
+        if state == 'Halted':
+            self.row_label.set_label('Start qube')
+            self.command = 'qvm-start'
+            self.icon.set_from_pixbuf(load_icon("qappmenu-start", size=None,
+                                                pixel_size=15))
 
-        if (
-            vm_name == "dom0"
-            or (apps_tab and is_dispvm_template and self.state != "Running")
-        ):
-            self.row_label.set_label(" ")
-            self.set_sensitive(False)
-            self.command = None
-            self.icon.hide()
             return
-
-        self.set_sensitive(True)
-        self.icon.show()
-        if self.state == "Halted" and not (is_dispvm_template and apps_tab):
-            self.row_label.set_label("Start qube")
-            self.command = "qvm-start"
-            self.icon.set_from_pixbuf(
-                load_icon("qappmenu-start", size=None, pixel_size=15)
-            )
-            return
-        if self.state == "Transient":
-            self.row_label.set_label("Kill qube")
-            self.command = "qvm-kill"
-            self.icon.set_from_pixbuf(
-                load_icon("qappmenu-shutdown", size=None, pixel_size=15)
-            )
-            return
-        if self.state == "Running":
-            self.row_label.set_label("Shutdown qube")
-            self.command = "qvm-shutdown"
-            self.icon.set_from_pixbuf(
-                load_icon("qappmenu-shutdown", size=None, pixel_size=15)
-            )
-            return
-        if self.state == "Paused":
-            self.row_label.set_label("Unpause qube")
-            self.command = "qvm-unpause"
-            self.icon.set_from_pixbuf(
-                load_icon("qappmenu-start", size=None, pixel_size=15)
-            )
+        if state == 'Paused':
+            self.row_label.set_label('Unpause qube')
+            self.command = 'qvm-unpause'
+            self.icon.set_from_pixbuf(load_icon("qappmenu-start", size=None,
+                                                pixel_size=15))
             return
 
 
@@ -553,28 +498,25 @@ class PauseControlItem(ControlRow):
     """
     Control Row item representing pausing VM: visible only when it's running.
     """
-
     def __init__(self):
         super().__init__()
-        self.icon.set_from_pixbuf(load_icon("qappmenu-pause", size=None, pixel_size=15))
+        self.icon.set_from_pixbuf(load_icon("qappmenu-pause", size=None,
+                                            pixel_size=15))
         self.state = None
 
-    def update_state(self, vm_entry: VMEntry, apps_tab: bool = False):
+    def update_state(self, state):
         """
         Update own state (visibility/text/sensitivity) based on provided VM
         state.
         """
-        # pylint: disable=unused-argument
-        vm_name = vm_entry.vm_name
-        self.state = vm_entry.power_state
-
-        if self.state == "Running" and vm_name != "dom0":
-            self.row_label.set_label("Pause qube")
+        self.state = state
+        if state == 'Running':
+            self.row_label.set_label('Pause qube')
             self.set_sensitive(True)
-            self.command = "qvm-pause"
+            self.command = 'qvm-pause'
             self.icon.show()
             return
-        self.row_label.set_label(" ")
+        self.row_label.set_label(' ')
         self.set_sensitive(False)
         self.command = None
         self.icon.hide()
@@ -584,12 +526,11 @@ class ControlList(Gtk.ListBox):
     """
     ListBox containing VM state control items.
     """
-
     def __init__(self, app_page):
         super().__init__()
         self.app_page = app_page
 
-        self.get_style_context().add_class("control_panel")
+        self.get_style_context().add_class('control_panel')
 
         self.settings_item = SettingsEntry(self.app_page.desktop_file_manager)
 
@@ -599,12 +540,12 @@ class ControlList(Gtk.ListBox):
         self.add(self.start_item)
         self.add(self.pause_item)
 
-    def update_visibility(self, vm_entry: VMEntry, apps_tab: bool = False):
+    def update_visibility(self, state):
         """
         Update children's state based on provided VM state.
         """
         for row in self.get_children():
-            row.update_state(vm_entry, apps_tab)
+            row.update_state(state)
 
 
 class KeynavController:
@@ -613,12 +554,11 @@ class KeynavController:
     not enough, namely, when we have a bunch of ListBoxes stacked on top of
      each other.
     """
-
     def __init__(self, widgets_in_order: List[Gtk.ListBox]):
         self.widgets_in_order = widgets_in_order
 
         for widget in self.widgets_in_order:
-            widget.connect("keynav-failed", self._keynav_failed)
+            widget.connect('keynav-failed', self._keynav_failed)
 
     def get_neighbor(self, widget: Gtk.ListBox, direction: Gtk.DirectionType):
         """Get next widget in given direction"""
@@ -629,7 +569,8 @@ class KeynavController:
             return self.widgets_in_order[(i + 1) % len(self.widgets_in_order)]
         return None
 
-    def _keynav_failed(self, widget: Gtk.ListBox, direction: Gtk.DirectionType):
+    def _keynav_failed(self, widget: Gtk.ListBox,
+                       direction: Gtk.DirectionType):
         """
         Callback to be performed when keyboard nav fails. Attempts to
         find next widget and move keyboard focus to it.
@@ -638,8 +579,7 @@ class KeynavController:
         if not next_widget:
             return
         next_focus_widget = get_visible_child(
-            next_widget, reverse=direction == Gtk.DirectionType.UP
-        )
+            next_widget, reverse=direction == Gtk.DirectionType.UP)
         if next_focus_widget:
             widget.select_row(None)
             next_focus_widget.grab_focus()
