@@ -26,15 +26,13 @@ import gi
 
 import qubesadmin.vm
 
-gi.require_version("Gtk", "3.0")
+gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk, GdkPixbuf, GLib
 
 
-def load_icon(
-    icon_name,
-    size: Optional[Gtk.IconSize] = Gtk.IconSize.LARGE_TOOLBAR,
-    pixel_size: Optional[int] = None,
-):
+def load_icon(icon_name,
+              size: Optional[Gtk.IconSize] = Gtk.IconSize.LARGE_TOOLBAR,
+              pixel_size: Optional[int] = None):
     """Load icon from provided name, if available. If not, attempt to treat
     provided name as a path. If icon not found in any of the above ways,
     load a blank icon of specified size.
@@ -51,32 +49,30 @@ def load_icon(
         try:
             # icon name is a path
             image: GdkPixbuf.Pixbuf = Gtk.IconTheme.get_default().load_icon(
-                icon_name, width, Gtk.IconLookupFlags.FORCE_SIZE
-            )
+                icon_name, width, Gtk.IconLookupFlags.FORCE_SIZE)
             return image
         except (TypeError, GLib.Error):
             # icon not found in any way
             pixbuf: GdkPixbuf.Pixbuf = GdkPixbuf.Pixbuf.new(
-                GdkPixbuf.Colorspace.RGB, True, 8, width, height
-            )
+                GdkPixbuf.Colorspace.RGB, True, 8, width, height)
             pixbuf.fill(0x000)
             return pixbuf
 
-
 def show_error(title, text):
     """
     Helper function to display error messages.
     """
-    dialog = Gtk.MessageDialog(None, 0, Gtk.MessageType.ERROR, Gtk.ButtonsType.OK)
+    dialog = Gtk.MessageDialog(
+        None, 0, Gtk.MessageType.ERROR, Gtk.ButtonsType.OK)
     dialog.set_title(title)
     dialog.set_markup(GLib.markup_escape_text(text))
     dialog.connect("response", lambda *x: dialog.destroy())
     dialog.show()
 
-
 def parse_search(search_text: str) -> List[str]:
     """Parse search text into separate words"""
-    search_words = search_text.lower().replace("-", " ").replace("_", " ").split(" ")
+    search_words = search_text.lower().replace(
+        '-', ' ').replace('_', ' ').split(' ')
     return [w for w in search_words if w]
 
 
@@ -96,9 +92,8 @@ def text_search(search_word: str, text_words: List[str]):
     return 0
 
 
-def highlight_words(
-    labels: List[Gtk.Label], search_words: List[str], hl_tag: Optional[str] = None
-) -> None:
+def highlight_words(labels: List[Gtk.Label], search_words: List[str],
+                    hl_tag: Optional[str] = None) -> None:
     """Highlight provided search_words in the provided labels."""
     if not labels:
         return
@@ -128,24 +123,23 @@ def highlight_words(
         if not found_intervals:
             continue
 
-        found_intervals.sort(key=lambda x: x[0])
+        found_intervals.sort(key= lambda x: x[0])
         result_intervals = [found_intervals[0]]
         for interval in found_intervals[1:]:
             if interval[0] <= result_intervals[-1][1]:
-                result_intervals[-1] = (
-                    result_intervals[-1][0],
-                    max(result_intervals[-1][1], interval[1]),
-                )
+                result_intervals[-1] = \
+                    (result_intervals[-1][0],
+                     max(result_intervals[-1][1], interval[1]))
             else:
                 result_intervals.append(interval)
 
         markup_list = []
         last_start = 0
-        for start, end in result_intervals:
+        for start, end in reversed(result_intervals):
             markup_list.append(GLib.markup_escape_text(text[last_start:start]))
             markup_list.append(hl_tag)
             markup_list.append(GLib.markup_escape_text(text[start:end]))
-            markup_list.append("</span>")
+            markup_list.append('</span>')
             last_start = end
         markup_list.append(GLib.markup_escape_text(text[last_start:]))
 
@@ -172,23 +166,24 @@ def add_to_feature(vm: qubesadmin.vm.QubesVM, feature_name: str, text: str):
     """
     current_feature = vm.features.get(feature_name)
     if current_feature:
-        feature_list = current_feature.split(" ")
+        feature_list = current_feature.split(' ')
     else:
         feature_list = []
 
     if text in feature_list:
         return
     feature_list.append(text)
-    vm.features[feature_name] = " ".join(feature_list)
+    vm.features[feature_name] = ' '.join(feature_list)
 
 
-def remove_from_feature(vm: qubesadmin.vm.QubesVM, feature_name: str, text: str):
+def remove_from_feature(vm: qubesadmin.vm.QubesVM,
+                        feature_name: str, text: str):
     """
     Remove a given string to a feature containing a list of space-separated
      strings.Can raise ValueError if ext was not found in the feature.
     """
-    current_feature = vm.features.get(feature_name, "").split(" ")
+    current_feature = vm.features.get(feature_name, '').split(' ')
 
     current_feature.remove(text)
 
-    vm.features[feature_name] = " ".join(current_feature)
+    vm.features[feature_name] = ' '.join(current_feature)
