@@ -21,7 +21,6 @@
 Helper class that manages all events related to VMs.
 """
 import qubesadmin.events
-import qubesadmin.exc
 from qubesadmin.vm import QubesVM
 from typing import Optional, Dict, List, Callable
 
@@ -34,47 +33,35 @@ class VMEntry:
     much data as possible and update it on events, sending also information
     to all related menu entries to update themselves.
     """
-
     def __init__(self, vm: QubesVM):
         self.vm = vm
         self.vm_name = str(vm)
         self.vm_klass = vm.klass
 
-        if self.vm.klass == "DispVM" and self.vm.auto_cleanup:
+        if self.vm.klass == 'DispVM' and self.vm.auto_cleanup:
             self.parent_vm = self.vm.template
-            self.sort_name = (
-                f"{str(self.parent_vm.name).lower()} :{self.vm_name.lower()}"
-            )
+            self.sort_name = \
+                f'{str(self.parent_vm.name).lower()} :{self.vm_name.lower()}'
         else:
             self.parent_vm = None
             # the space here is to assure correct sorting for dispvm children
             self.sort_name = self.vm_name.lower() + " "
 
-        try:
-            self._internal = bool(
-                self.vm.features.check_with_template("internal", False)
-            )
-        except qubesadmin.exc.QubesDaemonAccessError:
-            self._internal = False
         self._servicevm = bool(self.vm.features.get("servicevm", False))
-        self._is_dispvm_template = getattr(self.vm, "template_for_dispvms", False)
-        self._has_network = self.vm.is_networked() if vm.klass != "AdminVM" else False
-        self._vm_icon_name = getattr(
-            self.vm, "icon", getattr(self.vm.label, "icon", None)
-        )
+        self._is_dispvm_template = getattr(
+            self.vm, 'template_for_dispvms', False)
+        self._has_network = \
+            self.vm.is_networked() if vm.klass != 'AdminVM' else False
+        self._vm_icon_name = getattr(self.vm, 'icon',
+                                     getattr(self.vm.label, 'icon', None))
         self._power_state = self.vm.get_power_state()
         self.show_dispvm_template_in_apps = bool(
-            vm.features.get("appmenus-dispvm", False)
-        )
+            vm.features.get('appmenus-dispvm', False))
         self.entries: List = []
 
-    def update_entries(
-        self,
-        update_power_state=False,
-        update_label=False,
-        update_has_network=False,
-        update_type=False,
-    ):
+    def update_entries(self, update_power_state=False,
+                       update_label=False,
+                       update_has_network=False, update_type=False):
         """
         Update all related menu entries.
         :param update_power_state: did power state change?
@@ -83,12 +70,8 @@ class VMEntry:
         :param update_type: did type change?
         """
         for entry in self.entries:
-            entry.update_contents(
-                update_power_state,
-                update_label,
-                update_has_network,
-                update_type,
-            )
+            entry.update_contents(update_power_state, update_label,
+                                  update_has_network, update_type)
 
     @property
     def power_state(self):
@@ -112,7 +95,7 @@ class VMEntry:
 
     @vm_icon_name.setter
     def vm_icon_name(self, _new_value):
-        self._vm_icon_name = getattr(self.vm, "icon", self.vm.label.icon)
+        self._vm_icon_name = getattr(self.vm, 'icon', self.vm.label.icon)
         self.update_entries(update_label=True)
 
     @property
@@ -136,16 +119,6 @@ class VMEntry:
         self._is_dispvm_template = new_value
         self.update_entries(update_type=True)
 
-    @property
-    def internal(self):
-        """Is the VM internal"""
-        return self._internal
-
-    @internal.setter
-    def internal(self, new_value):
-        self._internal = new_value
-        self.update_entries(update_type=True)
-
     @property
     def service_vm(self):
         """Does the VM provide network"""
@@ -159,13 +132,11 @@ class VMEntry:
     @property
     def show_in_apps(self):
         """Should this qube be shown in the Apps section of the menu?"""
-        if self.internal:
-            return False
         if self.service_vm:
             return False
-        if self.vm_klass == "TemplateVM":
+        if self.vm_klass == 'TemplateVM':
             return False
-        if self.vm_klass == "AdminVM":
+        if self.vm_klass == 'AdminVM':
             return False
         if self.is_dispvm_template and not self.show_dispvm_template_in_apps:
             return False
@@ -175,26 +146,28 @@ class VMEntry:
     def _escaped_name(self) -> str:
         """Name escaped according to rules from desktop-linux-common
         package"""
-        return self.vm_name.replace("_", "_u").replace("-", "_d").replace(".", "_p")
+        return (self.vm_name.replace('_', '_u').
+                replace('-', '_d').replace('.', '_p'))
 
     @property
     def settings_desktop_file_name(self) -> str:
         """
         Name of relevant .desktop vm settings file.
         """
-        return "org.qubes-os.qubes-vm-settings._" + self._escaped_name + ".desktop"
+        return ('org.qubes-os.qubes-vm-settings._' +
+                self._escaped_name + '.desktop')
 
     @property
     def start_vm_desktop_file_name(self) -> str:
         """
         Name of relevant .desktop start vm file.
         """
-        return "org.qubes-os.vm._" + self._escaped_name + ".qubes-start.desktop"
+        return ('org.qubes-os.vm._' + self._escaped_name +
+                '.qubes-start.desktop')
 
 
 class VMManager:
     """A helper class that watches for VM-related events"""
-
     def __init__(self, qapp: qubesadmin.Qubes, dispatcher):
         self.qapp = qapp
         self.dispatcher = dispatcher
@@ -221,11 +194,8 @@ class VMManager:
             vm: QubesVM = self.qapp.domains[vm_name]
         except KeyError:
             return None
-        try:
-            if vm.features.check_with_template("internal", False):
-                return None
-        except qubesadmin.exc.QubesDaemonAccessError:
-            pass
+        if vm.features.get('internal', False):
+            return None
 
         return self._add_vm(vm)
 
@@ -265,49 +235,43 @@ class VMManager:
             state = constants.STATE_DICTIONARY[event]
             vm_entry.power_state = state
 
-    def _update_domain_property(self, vm_name, event, newvalue, *_args, **_kwargs):
+    def _update_domain_property(self, vm_name, event, newvalue,
+                                *_args, **_kwargs):
         vm_entry = self.load_vm_from_name(vm_name)
 
         if not vm_entry:
             return
 
-        if newvalue == "False":
+        if newvalue == 'False':
             newvalue = False
 
         try:
-            if event == "property-set:label":
+            if event == 'property-set:label':
                 vm_entry.vm_icon_name = newvalue
-            elif event == "property-set:netvm":
+            elif event == 'property-set:netvm':
                 vm_entry.has_network = vm_entry.vm.is_networked()
-            elif event == "property-set:template_for_dispvms":
+            elif event == 'property-set:template_for_dispvms':
                 vm_entry.is_dispvm_template = newvalue
         except Exception:  # pylint: disable=broad-except
             # dispatcher functions cannot raise any Exception, because
             # it will disable any future event handling
             pass
 
-    def _update_domain_feature(self, vm, _event, feature=None, value=None, **_kwargs):
+    def _update_domain_feature(self, vm, _event, feature=None, value=None,
+                               **_kwargs):
         vm_entry = self.load_vm_from_name(vm)
 
         if not vm_entry:
             return
 
-        if value == "False":
+        if value == 'False':
             value = False
         value = bool(value)
 
         try:
-            if feature == "internal":
-                vm_entry.internal = value
-                for derived in self.qapp.domains:
-                    if not getattr(derived, "template", None) == vm:
-                        continue
-                    derived_vm_entry = self.load_vm_from_name(derived)
-                    if derived_vm_entry:
-                        derived_vm_entry.internal = value
-            if feature == "servicevm":
+            if feature == 'servicevm':
                 vm_entry.service_vm = value
-            if feature == "appmenus-dispvm":
+            if feature == 'appmenus-dispvm':
                 vm_entry.show_dispvm_template_in_apps = value
         except Exception:  # pylint: disable=broad-except
             # dispatcher functions cannot raise any Exception, because
@@ -325,38 +289,35 @@ class VMManager:
 
     def register_events(self):
         """Register handlers for all relevant VM events."""
-        self.dispatcher.add_handler("domain-pre-start", self._update_domain_state)
-        self.dispatcher.add_handler("domain-start", self._update_domain_state)
-        self.dispatcher.add_handler("domain-start-failed", self._update_domain_state)
-        self.dispatcher.add_handler("domain-paused", self._update_domain_state)
-        self.dispatcher.add_handler("domain-unpaused", self._update_domain_state)
-        self.dispatcher.add_handler("domain-shutdown", self._update_domain_state)
-        self.dispatcher.add_handler("domain-pre-shutdown", self._update_domain_state)
-        self.dispatcher.add_handler("domain-shutdown-failed", self._update_domain_state)
+        self.dispatcher.add_handler('domain-pre-start',
+                                    self._update_domain_state)
+        self.dispatcher.add_handler('domain-start', self._update_domain_state)
+        self.dispatcher.add_handler('domain-start-failed',
+                                    self._update_domain_state)
+        self.dispatcher.add_handler('domain-paused', self._update_domain_state)
+        self.dispatcher.add_handler('domain-unpaused',
+                                    self._update_domain_state)
+        self.dispatcher.add_handler('domain-shutdown',
+                                    self._update_domain_state)
+        self.dispatcher.add_handler('domain-pre-shutdown',
+                                    self._update_domain_state)
+        self.dispatcher.add_handler('domain-shutdown-failed',
+                                    self._update_domain_state)
 
-        self.dispatcher.add_handler("domain-add", self._add_domain)
-        self.dispatcher.add_handler("domain-delete", self._remove_domain)
+        self.dispatcher.add_handler('domain-add', self._add_domain)
+        self.dispatcher.add_handler('domain-delete', self._remove_domain)
 
-        self.dispatcher.add_handler("property-set:netvm", self._update_domain_property)
-        self.dispatcher.add_handler("property-set:label", self._update_domain_property)
-        self.dispatcher.add_handler(
-            "property-set:template_for_dispvms", self._update_domain_property
-        )
-        self.dispatcher.add_handler(
-            "domain-feature-set:servicevm", self._update_domain_feature
-        )
-        self.dispatcher.add_handler(
-            "domain-feature-delete:servicevm", self._update_domain_feature
-        )
-        self.dispatcher.add_handler(
-            "domain-feature-set:appmenus-dispvm", self._update_domain_feature
-        )
-        self.dispatcher.add_handler(
-            "domain-feature-delete:appmenus-dispvm", self._update_domain_feature
-        )
-        self.dispatcher.add_handler(
-            "domain-feature-set:internal", self._update_domain_feature
-        )
-        self.dispatcher.add_handler(
-            "domain-feature-delete:internal", self._update_domain_feature
-        )
+        self.dispatcher.add_handler('property-set:netvm',
+                                    self._update_domain_property)
+        self.dispatcher.add_handler('property-set:label',
+                                    self._update_domain_property)
+        self.dispatcher.add_handler('property-set:template_for_dispvms',
+                                    self._update_domain_property)
+        self.dispatcher.add_handler('domain-feature-set:servicevm',
+                                    self._update_domain_feature)
+        self.dispatcher.add_handler('domain-feature-delete:servicevm',
+                                    self._update_domain_feature)
+        self.dispatcher.add_handler('domain-feature-set:appmenus-dispvm',
+                                    self._update_domain_feature)
+        self.dispatcher.add_handler('domain-feature-delete:appmenus-dispvm',
+                                    self._update_domain_feature)
